==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/GetRuleGroupResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRuleGroupResponse(
    ruleGroup: Option[zio.aws.waf.model.RuleGroup] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetRuleGroupResponse = {
    import GetRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
      .builder()
      .optionallyWith(ruleGroup.map(value => value.buildAwsValue()))(
        _.ruleGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetRuleGroupResponse.ReadOnly =
    zio.aws.waf.model.GetRuleGroupResponse.wrap(buildAwsValue())
}
object GetRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetRuleGroupResponse = zio.aws.waf.model
      .GetRuleGroupResponse(ruleGroup.map(value => value.asEditable))
    def ruleGroup: Option[zio.aws.waf.model.RuleGroup.ReadOnly]
    def getRuleGroup: ZIO[Any, AwsError, zio.aws.waf.model.RuleGroup.ReadOnly] =
      AwsError.unwrapOptionField("ruleGroup", ruleGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
  ) extends zio.aws.waf.model.GetRuleGroupResponse.ReadOnly {
    override val ruleGroup: Option[zio.aws.waf.model.RuleGroup.ReadOnly] = scala
      .Option(impl.ruleGroup())
      .map(value => zio.aws.waf.model.RuleGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
  ): zio.aws.waf.model.GetRuleGroupResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/GetRuleGroupResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRuleGroupResponse(
    ruleGroup: Optional[zio.aws.waf.model.RuleGroup] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetRuleGroupResponse = {
    import GetRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
      .builder()
      .optionallyWith(ruleGroup.map(value => value.buildAwsValue()))(
        _.ruleGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetRuleGroupResponse.ReadOnly =
    zio.aws.waf.model.GetRuleGroupResponse.wrap(buildAwsValue())
}
object GetRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetRuleGroupResponse = zio.aws.waf.model
      .GetRuleGroupResponse(ruleGroup.map(value => value.asEditable))
    def ruleGroup: Optional[zio.aws.waf.model.RuleGroup.ReadOnly]
    def getRuleGroup: ZIO[Any, AwsError, zio.aws.waf.model.RuleGroup.ReadOnly] =
      AwsError.unwrapOptionField("ruleGroup", ruleGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
  ) extends zio.aws.waf.model.GetRuleGroupResponse.ReadOnly {
    override val ruleGroup: Optional[zio.aws.waf.model.RuleGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ruleGroup())
        .map(value => zio.aws.waf.model.RuleGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetRuleGroupResponse
  ): zio.aws.waf.model.GetRuleGroupResponse.ReadOnly = new Wrapper(impl)
}
